yakumo.nova.v2.volume_attachment

Package yakumo :: Package nova :: Package v2 :: Module volume_attachment |
[hide private]
[frames] | no frames]

# Module volume_attachment

source code

Resource class and its manager for volume attachment in Compute API v2

Classes | [hide private]
| Resource Resource class for volume attachment in Compute API v2
| Manager Manager class for volume attachment in Compute API v2

Variables | [hide private]
| ATTRIBUTE_MAPPING = ``[``(``'``id``'``,` `'``id``'``,` <yakumo.mapper.NoopClass obj`...``
| __package__ = ``'``yakumo.nova.v2``'``

Variables Details | [hide private]

  ### ATTRIBUTE_MAPPING Value:
      [('id', 'id', mapper.Noop), ('device', 'device', mapper.Noop), ('serve
      r', 'serverId', mapper.Resource('nova.server')), ('volume', 'volumeId'
      , mapper.Resource('volume')),]